==> nextcloud-23.0.9.tgz: nextcloud/apps/weather_status/l10n/nl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Onbekend adres",
    "No result." : "Geen resultaat.",
    "Malformed JSON data." : "Onjuist opgemaakte JSON-gegevens.",
    "Error" : "Fout",
    "Weather status" : "Weerstatus",
    "Weather status in your dashboard" : "Weerstatus in je dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Weerbericht is geïntegreerd in de dashboard app\nDe gebruikerslocatie kan automatisch worden bepaald of handmatig worden ingegeven. Een 6 uurs weersverwachting wordt getoond.\nDeze status kan ook op andere plaatsen worden geïntegreerd zoals in de agenda-app.",
    "Detect location" : "Locatie detecteren",
    "Set custom address" : "Aangepast adres instellen",
    "Favorites" : "Favorieten",
    "{temperature} {unit} clear sky later today" : "{temperature}{unit} later vandaag onbewolkt ",
    "{temperature} {unit} clear sky" : "{temperature}{unit} onbewolkt",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} bewolkt later vandaag",
    "{temperature} {unit} cloudy" : "{temperature} {unit} bewolkt",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} half bewolkt later vandaag",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} half bewolkt",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} mistig later vandaag",
    "{temperature} {unit} foggy" : "{temperature} {unit} mistig",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lichte regen",
    "{temperature} {unit} rainfall" : "{temperature} {unit} regen",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} zware regen",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} regenbuien",
    "More weather for {adr}" : "Meer weer voor {adr}",
    "Loading weather" : "Weergegevens ophalen",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add as favorite" : "Toevoegen als favoriet",
    "You are not logged in." : "Je bent niet ingelogd.",
    "There was an error getting the weather status information." : "Er is een fout opgetreden bij het ophalen van de weerinformatie.",
    "No weather information found" : "Geen weer informatie gevonden.",
    "Location not found" : "Locatie niet gevonden",
    "There was an error setting the location address." : "Er is een fout opgetreden bij het zetten van het locatie adres.",
    "There was an error setting the location." : "Er is een fout opgetreden bij het vastleggen van de locatie.",
    "There was an error saving the mode." : "Er was een fout in het vastleggen van de modus.",
    "There was an error using personal address." : "Er was een fout bij het gebruiken van je persoonlijke adres.",
    "Set location for weather" : "Stel je locatie voor het weer in.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature}{unit} Onbewolkt om {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewolkt om {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Redelijk dag om {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Redelijk nacht om {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Half bewolkt om {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mist om {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} lichte regen om {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen om {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Zware regen om {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenbuien om {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lichte regenbuien om {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Hevige regenbuien om {time}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/weather_status/l10n/nl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Onbekend adres",
    "No result." : "Geen resultaat.",
    "Malformed JSON data." : "Onjuist opgemaakte JSON-gegevens.",
    "Error" : "Fout",
    "Weather status" : "Weerstatus",
    "Weather status in your dashboard" : "Weerstatus in je dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Weerbericht is geïntegreerd in de dashboard app\nDe gebruikerslocatie kan automatisch worden bepaald of handmatig worden ingegeven. Een 6 uurs weersverwachting wordt getoond.\nDeze status kan ook op andere plaatsen worden geïntegreerd zoals in de agenda-app.",
    "Detect location" : "Locatie detecteren",
    "Set custom address" : "Aangepast adres instellen",
    "Favorites" : "Favorieten",
    "{temperature} {unit} clear sky later today" : "{temperature}{unit} later vandaag onbewolkt ",
    "{temperature} {unit} clear sky" : "{temperature}{unit} onbewolkt",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} bewolkt later vandaag",
    "{temperature} {unit} cloudy" : "{temperature} {unit} bewolkt",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} lekker weer later vandaag",
    "{temperature} {unit} fair weather" : "{temperature} {unit} lekker weer",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} half bewolkt later vandaag",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} half bewolkt",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} mistig later vandaag",
    "{temperature} {unit} foggy" : "{temperature} {unit} mistig",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} lichte regen later vandaag",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lichte regen",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} regen later vandaag",
    "{temperature} {unit} rainfall" : "{temperature} {unit} regen",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} zware regen later vandaag",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} zware regen",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} regenbuien later vandaag",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} regenbuien",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} lichte regenbuien later vandaag",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} lichte regenbuien",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} zware regenbuien later vandaag",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} zware regenbuien",
    "More weather for {adr}" : "Meer weer voor {adr}",
    "Loading weather" : "Weergegevens ophalen",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add as favorite" : "Toevoegen als favoriet",
    "You are not logged in." : "Je bent niet ingelogd.",
    "There was an error getting the weather status information." : "Er is een fout opgetreden bij het ophalen van de weerinformatie.",
    "No weather information found" : "Geen weer informatie gevonden.",
    "Location not found" : "Locatie niet gevonden",
    "There was an error setting the location address." : "Er is een fout opgetreden bij het zetten van het locatie adres.",
    "There was an error setting the location." : "Er is een fout opgetreden bij het vastleggen van de locatie.",
    "There was an error saving the mode." : "Er was een fout in het vastleggen van de modus.",
    "There was an error using personal address." : "Er was een fout bij het gebruiken van je persoonlijke adres.",
    "Set location for weather" : "Stel je locatie voor het weer in.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature}{unit} Onbewolkt om {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewolkt om {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Redelijk dag om {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Redelijk nacht om {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Half bewolkt om {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mist om {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} lichte regen om {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen om {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Zware regen om {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenbuien om {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lichte regenbuien om {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Hevige regenbuien om {time}"
},
"nplurals=2; plural=(n != 1);");
